<?php
/*
 * Comment display template of Forestly.
 *
 * @package forestly
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() )
	return;
?>

<div id="comments" class="comments-area">

	<?php if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
				printf( _n( 'One Comment on &ldquo;%2$s&rdquo;', '%1$s Comments on &ldquo;%2$s&rdquo;', get_comments_number(), 'forestly' ),
					number_format_i18n( get_comments_number() ), '<span>' . get_the_title() . '</span>' );
			?>
		</h2>

		<ol class="commentlist">
			<?php wp_list_comments( array( 'callback' => 'fosforit_comment', 'style' => 'ol' ) ); ?>
		</ol><!-- .commentlist -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
		<nav id="comment-nav-below" class="navigation" role="navigation">
			<h1 class="assistive-text section-heading"><?php _e( 'Comment navigation', 'forestly' ); ?></h1>
			<div class="nav-previous"><?php previous_comments_link( __( '&laquo; Older Comments', 'forestly' ) ); ?></div>
			<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &raquo;', 'forestly' ) ); ?></div>
		</nav>
		<?php endif; // check for comment navigation ?>

		<?php
		/* If there are no comments and comments are closed, let's leave a note.
		 * But we only want the note on posts and pages that had comments in the first place.
		 */
		if ( ! comments_open() && get_comments_number() ) : ?>
		<p class="nocomments"><?php _e( 'Comments are closed.' , 'forestly' ); ?></p>
		<?php endif; ?>

	<?php endif; // have_comments() ?>

	<?php if(of_get_option('display_allowed_comment_html') == '1'){ ?>
		<?php comment_form(array('comment_notes_after' => '<p class="form-allowed-tags">'.__('You can use the following HTML Tags and Attributes:', 'forestly').'
		&lt;a href="" title=""&gt; &lt;abbr title=""&gt; &lt;acronym title=""&gt; &lt;b&gt; &lt;blockquote cite=""&gt;
		&lt;cite&gt; &lt;code&gt; &lt;del datetime=""&gt; &lt;em&gt; &lt;i&gt; &lt;q cite=""&gt; &lt;strike&gt;
		&lt;strong&gt; &lt;img src="" alt="" class="" width="" height=""&gt;</p>')); ?>
	<?php } else { ?>
		<?php comment_form(array('comment_notes_after' => '')); ?>
	<?php } ?>

</div><!-- #comments .comments-area -->
