<?php
/*
 * Content display template, used for both single and index/category/search pages.
 * Forestly uses custom excerpts on search, home, category and tag pages.
 * 
 * @package forestly
 */
?>

<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
	<?php if ( is_sticky() && is_home() && ! is_paged() ) : // for top sticky post ?>
		<div class="featured-post">
			<?php _e( 'Featured Article', 'forestly' ); ?>
		</div>
	<?php endif; ?>
	<header class="entry-header">
		<?php if ( is_single() ) : ?>
			<?php if( of_get_option('display_title_on_single_posts') == '1') { ?>
				<h1 class="entry-title"><?php the_title(); ?></h1>
			<?php } ?>
		<?php else : ?>
		<h1 class="entry-title">
			<a href="<?php the_permalink(); ?>" 
				title="<?php echo esc_attr( sprintf( __( 'Permalink to %s', 'forestly' ), 
				the_title_attribute( 'echo=0' ) ) ); ?>" rel="bookmark"><?php the_title(); ?>
			</a>
		</h1>
		<?php endif; // is_single() ?>
		<?php if ( !((is_sticky() && is_home())
		|| (of_get_option('activate_excerpts_on_home') == '1'))
		|| is_single()
		) : //for date ?>	
			<div class="below-title-meta">
				<div class="adt">
					<span class="fa fa-user"></span>
					<span> <?php _e('By','forestly'); ?></span>
					<span class="author"> <?php echo the_author_posts_link(); ?></span>
					<span class="meta-sep"> &nbsp; </span> 
					<span class="fa fa-clock-o"></span>
					<span> <?php echo get_the_date(); ?></span>
				</div>
				<div class="adt-comment">
					<a class="link-comments fa fa-comments" href="<?php  comments_link(); ?>">
						<?php comments_number('0','1','%'); ?>
					</a>
				</div>       
			</div><!-- below title meta end -->
		<?php endif; // display meta-date on single page() ?>
		</header><!-- .entry-header -->
	<?php // Display Excerpts for Search, home, category and tag pages ?>
	<?php if ( (is_search() && (of_get_option('activate_excerpts_on_search') == true))
	|| (is_home() && (of_get_option('activate_excerpts_on_home') == true))
	|| (is_category() && (of_get_option('activate_excerpts_on_category') == true))
	|| (is_tag() && (of_get_option('activate_excerpts_on_tag') == true))
	|| (is_archive() && (of_get_option('activate_excerpts_on_archive') == true))
	|| (is_sticky() && is_home() && (of_get_option('activate_excerpts_on_sticky') == true))
	) : ?>
		<div class="entry-summary">
			<!-- Forestly home page thumbnail with custom excerpt -->
			<div class="excerpt-thumb">
				<?php if (  (function_exists('has_post_thumbnail')) && (has_post_thumbnail())) : ?>
					<a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'forestly' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark">
						<?php the_post_thumbnail('excerpt-thumbnail', 'class=alignleft'); ?>
					</a>
				<?php else :
					echo forestly_get_first_image();
				endif ; ?>
			</div>
			<?php the_excerpt(); ?>
		</div><!-- .entry-summary -->
	<?php else : ?>
		<div class="entry-content">
			<?php the_content( __( 'Continue reading &raquo;', 'forestly' ) ); ?>
			<?php wp_link_pages( array( 'before' => '<div class="page-links">' . __( 'Pages:', 'forestly' ), 'after' => '</div>' ) ); ?>
		</div><!-- .entry-content -->
	<?php endif; ?>
	<footer class="entry-meta">
	<span class="fa fa-folder-open"></span> <span><?php _e( 'Category:','forestly' )?> <?php the_category(' '); ?></span> <?php if(has_tag()){ ?><span class="fa fa-tags"></span> <span><?php the_tags(); ?></span> <?php } ?>
		<?php edit_post_link( '<span class="edit-link fa fa-pencil"></span> '.__( 'Edit', 'forestly' ), '<span class="edit-link">', '</span>' ); ?>
		<?php // If a user has filled out their description and this is a multi-author blog, show a bio on their entries. ?>
		<?php if ( is_single() && get_the_author_meta( 'description' ) && (of_get_option('display_author_bio') == '1' )) : ?>
			<div class="author-info">
				<div class="author-avatar">
					<?php echo get_avatar( get_the_author_meta( 'user_email' ), apply_filters( 'fosforit_author_bio_avatar_size', 68 ) ); ?>
				</div><!-- .author-avatar -->
				<div class="author-description">
					<h2><?php printf( __( 'About %s', 'forestly' ), get_the_author() ); ?></h2>
					<p><?php the_author_meta( 'description' ); ?></p>
					<div class="author-link">
						<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author">
							<?php printf( __( 'View all posts by %s &raquo;', 'forestly' ), get_the_author() ); ?>
						</a>
					</div><!-- .author-link	-->
				</div><!-- .author-description -->
			</div><!-- .author-info -->
		<?php endif; ?>
	</footer><!-- .entry-meta -->
</article><!-- #post -->
